Quarterly Sales Report

# Quarterly Sales Report - Q3 2025

Below is the sales data broken down by region.

Region | Product | Q1 Sales | Q2 Sales | Q3 Sales | Total
--- | --- | --- | --- | --- | ---
North America | Widget A | 15000 | 18000 | 22000 | 55000
North America | Widget B | 8000 | 9500 | 11000 | 28500
Europe | Widget A | 12000 | 14000 | 16500 | 42500
Europe | Widget B | 6000 | 7200 | 8800 | 22000
Asia Pacific | Widget A | 9000 | 11000 | 13500 | 33500
Asia Pacific | Widget B | 4500 | 5800 | 7200 | 17500
Latin America | Widget A | 3000 | 3800 | 4500 | 11300
Latin America | Widget B | 1500 | 2000 | 2700 | 6200